package
Version:
v0.0.0-...-95c6a78
Opens a new window with list of versions in this module.
Published: May 1, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func ExtractPersistScript() (err error)
Extract persist shell-script
func GetIndexHtmlPath() (s string)
Get index.html path
func RemovePersistScript() (err error)
Remove persist shell-script
Source Files
¶
Click to show internal directories.
Click to hide internal directories.